Subject: [bug#45870] [PATCH core-updates 3/3] gnu: Replace all uses of texlive-union by texlive-updmap.cfg.

From: Maxim Cournoyer <[email-masked]>
Date: Thu, 14 Jan 2021 13:41:27 -0500

* doc/build.scm (pdf-manual) Replace texlive-union by texlive-updmap.cfg.
* gnu/packages/algebra.scm (pari-gp): Likewise.
* gnu/packages/bioinformatics.scm (discrover, velvet): Likewise.
* gnu/packages/chez.scm (chez-scheme, chez-web, chez-sockets): Likewise.
* gnu/packages/docbook.scm (dblatex): Likewise.
* gnu/packages/emacs-xyz.scm (emacs-auctex): Likewise.
* gnu/packages/engineering.scm (fastcap): Likewise.
* gnu/packages/guile-xyz.scm (emacsy, guile-cv): Likewise.
* gnu/packages/lisp.scm (sbcl): Likewise.
* gnu/packages/maths.scm (octave, hypre): Likewise.
* gnu/packages/music.scm (lilypond): Likewise.
* gnu/packages/plotutils.scm (asymptote): Likewise.
* gnu/packages/python-xyz.scm (python-numpy-documentation)
(python-matplotlib-documentation, python-ipython-documentation)
(python-pypandoc): Likewise.
* gnu/packages/radio.scm (gnuradio, libosmo-dsp): Likewise.
* gnu/packages/scheme.scm (mit-scheme): Likewise.
* gnu/packages/statistics.scm (r-with-tests): Likewise.
* gnu/packages/tex.scm (simple-texlive-package)
(texlive-xmltex, texlive-tiny, texlive-jadetex, teximpatient, lyx): Likewise.
---
 doc/build.scm                   |  2 +-
 gnu/packages/algebra.scm        |  2 +-
 gnu/packages/bioinformatics.scm |  4 ++--
 gnu/packages/chez.scm           |  6 +++---
 gnu/packages/docbook.scm        |  2 +-
 gnu/packages/emacs-xyz.scm      |  2 +-
 gnu/packages/engineering.scm    |  2 +-
 gnu/packages/guile-xyz.scm      |  4 ++--
 gnu/packages/lisp.scm           |  2 +-
 gnu/packages/maths.scm          |  4 ++--
 gnu/packages/music.scm          |  2 +-
 gnu/packages/plotutils.scm      |  2 +-
 gnu/packages/python-xyz.scm     | 10 +++++-----
 gnu/packages/radio.scm          |  4 ++--
 gnu/packages/scheme.scm         |  2 +-
 gnu/packages/statistics.scm     |  2 +-
 gnu/packages/tex.scm            | 10 +++++-----
 17 files changed, 31 insertions(+), 31 deletions(-)

diff --git a/doc/build.scm b/doc/build.scm
index d77fc0a700..abdcf43d96 100644
--- a/doc/build.scm
+++ b/doc/build.scm
@@ -736,7 +736,7 @@ makeinfo OPTIONS."
   ;; accented letters.
   ;;
   ;; (define texlive
-  ;;   (texlive-union (list texlive-tex-texinfo
+  ;;   (texlive-updmap.cfg (list texlive-tex-texinfo
   ;;                        texlive-generic-epsf
   ;;                        texlive-fonts-ec)))
 
diff --git a/gnu/packages/algebra.scm b/gnu/packages/algebra.scm
index 0350536061..b425c3b299 100644
--- a/gnu/packages/algebra.scm
+++ b/gnu/packages/algebra.scm
@@ -245,7 +245,7 @@ the real span of the lattice.")
                 "14xs90wrw8mbdx08hxlbhiahp6kgjq6yh27zjw7fvhfjx5nr84f8"))))
     (build-system gnu-build-system)
     (native-inputs
-     `(("texlive" ,(texlive-union
+     `(("texlive" ,(texlive-updmap.cfg
                     (list texlive-amsfonts)))))
     (inputs `(("gmp" ,gmp)
               ("libx11" ,libx11)
diff --git a/gnu/packages/bioinformatics.scm b/gnu/packages/bioinformatics.scm
index c3b1ec6678..058949618e 100644
--- a/gnu/packages/bioinformatics.scm
+++ b/gnu/packages/bioinformatics.scm
@@ -2904,7 +2904,7 @@ data and settings.")
        ("cairo" ,cairo)
        ("rmath-standalone" ,rmath-standalone)))
     (native-inputs
-     `(("texlive" ,(texlive-union (list texlive-cm
+     `(("texlive" ,(texlive-updmap.cfg (list texlive-cm
                                         texlive-amsfonts
 
                                         texlive-latex-doi
@@ -14186,7 +14186,7 @@ to an artifact/contaminant file.")
      `(("openmpi" ,openmpi)
        ("zlib" ,zlib)))
     (native-inputs
-     `(("texlive" ,(texlive-union (list texlive-latex-graphics
+     `(("texlive" ,(texlive-updmap.cfg (list texlive-latex-graphics
                                         texlive-latex-hyperref)))))
     (home-page "https://www.ebi.ac.uk/~zerbino/velvet/")
     (synopsis "Nucleic acid sequence assembler for very short reads")
diff --git a/gnu/packages/chez.scm b/gnu/packages/chez.scm
index 85a3bb1d1a..11cd04c161 100644
--- a/gnu/packages/chez.scm
+++ b/gnu/packages/chez.scm
@@ -88,7 +88,7 @@
        ("zlib:static" ,zlib "static")
        ("stex" ,stex)))
     (native-inputs
-     `(("texlive" ,(texlive-union (list texlive-latex-oberdiek
+     `(("texlive" ,(texlive-updmap.cfg (list texlive-latex-oberdiek
                                         texlive-generic-epsf)))
        ("ghostscript" ,ghostscript)
        ("netpbm" ,netpbm)))
@@ -273,7 +273,7 @@ and 32-bit PowerPC architectures.")
       (native-inputs
        `(("chez-scheme" ,chez-scheme)
          ("ghostscript" ,ghostscript)
-         ("texlive" ,(texlive-union (list texlive-latex-oberdiek
+         ("texlive" ,(texlive-updmap.cfg (list texlive-latex-oberdiek
                                           texlive-generic-epsf
                                           texlive-metapost
                                           texlive-fonts-charter
@@ -332,7 +332,7 @@ programming in Scheme.")
       (native-inputs
        `(("chez-scheme" ,chez-scheme)
          ("chez-web" ,chez-web)
-         ("texlive" ,(texlive-union (list texlive-pdftex)))))
+         ("texlive" ,(texlive-updmap.cfg (list texlive-pdftex)))))
       (arguments
        `(#:tests? #f              ; no tests
          #:phases
diff --git a/gnu/packages/docbook.scm b/gnu/packages/docbook.scm
index 21a4f7b45f..f797c97cf3 100644
--- a/gnu/packages/docbook.scm
+++ b/gnu/packages/docbook.scm
@@ -397,7 +397,7 @@ the in DocBook SGML DTDs.")
     (build-system python-build-system)
     ;; TODO: Add xfig/transfig for fig2dev utility
     (inputs
-     `(("texlive" ,(texlive-union (list texlive-amsfonts
+     `(("texlive" ,(texlive-updmap.cfg (list texlive-amsfonts
                                         texlive-latex-anysize
                                         texlive-latex-appendix
                                         texlive-latex-changebar
diff --git a/gnu/packages/emacs-xyz.scm b/gnu/packages/emacs-xyz.scm
index 81ae90ea31..d29eed0687 100644
--- a/gnu/packages/emacs-xyz.scm
+++ b/gnu/packages/emacs-xyz.scm
@@ -2118,7 +2118,7 @@ as a library for other Emacs packages.")
      `(("perl" ,perl)))
     (inputs
      `(("ghostscript" ,ghostscript)
-       ("texlive" ,(texlive-union (list texlive-amsfonts)))))
+       ("texlive" ,(texlive-updmap.cfg (list texlive-amsfonts)))))
     (home-page "https://www.gnu.org/software/auctex/")
     (synopsis "Integrated environment for TeX")
     (description
diff --git a/gnu/packages/engineering.scm b/gnu/packages/engineering.scm
index 3b8bcd9194..7928b4d06f 100644
--- a/gnu/packages/engineering.scm
+++ b/gnu/packages/engineering.scm
@@ -514,7 +514,7 @@ featuring various improvements and bug fixes.")))
      ;; FIXME: with texlive-tiny citation references are rendered as question
      ;; marks.  During the build warnings like these are printed:
      ;; LaTeX Warning: Citation `nabors91' on page 2 undefined on input line 3.
-     `(("texlive" ,(texlive-union (list texlive-fonts-amsfonts)))
+     `(("texlive" ,(texlive-updmap.cfg (list texlive-fonts-amsfonts)))
        ("ghostscript" ,ghostscript)))
     (arguments
      `(#:make-flags '("CC=gcc" "RM=rm" "SHELL=sh" "all")
diff --git a/gnu/packages/guile-xyz.scm b/gnu/packages/guile-xyz.scm
index c5eaa8a2ca..2dd8752fc8 100644
--- a/gnu/packages/guile-xyz.scm
+++ b/gnu/packages/guile-xyz.scm
@@ -3144,7 +3144,7 @@ API.")
        ("perl" ,perl)
        ("pkg-config" ,pkg-config)
        ("texinfo" ,texinfo)
-       ("texlive" ,(texlive-union (list texlive-generic-epsf)))))
+       ("texlive" ,(texlive-updmap.cfg (list texlive-generic-epsf)))))
     (inputs
      `(("dbus-glib" ,dbus-glib)
        ("guile" ,guile-3.0)
@@ -3421,7 +3421,7 @@ feature-set, fully programmable in Guile Scheme.")
        ("vigra-c" ,vigra-c)
        ("guile" ,guile-2.2)))
     (native-inputs
-     `(("texlive" ,(texlive-union (list texlive-booktabs
+     `(("texlive" ,(texlive-updmap.cfg (list texlive-booktabs
                                         texlive-lm
                                         texlive-siunitx
                                         texlive-standalone
diff --git a/gnu/packages/lisp.scm b/gnu/packages/lisp.scm
index e89d777d2c..7d65bfc887 100644
--- a/gnu/packages/lisp.scm
+++ b/gnu/packages/lisp.scm
@@ -434,7 +434,7 @@ an interpreter, a compiler, a debugger, and much more.")
        ("ed" ,ed)
        ("inetutils" ,inetutils)         ;for hostname(1)
        ("texinfo" ,texinfo)
-       ("texlive" ,(texlive-union (list texlive-tex-texinfo)))
+       ("texlive" ,(texlive-updmap.cfg (list texlive-tex-texinfo)))
        ("which" ,which)
        ("zlib" ,zlib)))
     (arguments
diff --git a/gnu/packages/maths.scm b/gnu/packages/maths.scm
index 4019c7efaf..d46cca8f3a 100644
--- a/gnu/packages/maths.scm
+++ b/gnu/packages/maths.scm
@@ -2010,7 +2010,7 @@ script files.")
        ,@(package-inputs octave-cli)))
     (native-inputs
      `(("qttools" , qttools) ;for lrelease
-       ("texlive" ,(texlive-union (list texlive-epsf))) ; for texi2dvi
+       ("texlive" ,(texlive-updmap.cfg (list texlive-epsf))) ; for texi2dvi
        ,@(package-native-inputs octave-cli)))
     (arguments
      (substitute-keyword-arguments (package-arguments octave-cli)
@@ -4464,7 +4464,7 @@ set.")
      `(("doc++" ,doc++)
        ("netpbm" ,netpbm)
        ("perl" ,perl)                   ; needed to run 'ppmquant' during tests
-       ("texlive" ,(texlive-union (list texlive-xypic
+       ("texlive" ,(texlive-updmap.cfg (list texlive-xypic
                                         texlive-cm
                                         texlive-latex-hyperref
                                         texlive-bibtex)))
diff --git a/gnu/packages/music.scm b/gnu/packages/music.scm
index b3c25a7943..cf4e068fad 100644
--- a/gnu/packages/music.scm
+++ b/gnu/packages/music.scm
@@ -1342,7 +1342,7 @@ and auto-mapping slices to MIDI note numbers.")
        ("gettext" ,gettext-minimal)
        ("imagemagick" ,imagemagick)
        ("netpbm" ,netpbm)               ;for pngtopnm
-       ("texlive" ,(texlive-union (list texlive-metapost
+       ("texlive" ,(texlive-updmap.cfg (list texlive-metapost
                                         texlive-generic-epsf
                                         texlive-lh
                                         texlive-latex-cyrillic)))
diff --git a/gnu/packages/plotutils.scm b/gnu/packages/plotutils.scm
index f23b56728a..8928bbddd5 100644
--- a/gnu/packages/plotutils.scm
+++ b/gnu/packages/plotutils.scm
@@ -226,7 +226,7 @@ colors, styles, options and details.")
        ("perl" ,perl)
        ("texinfo" ,texinfo)             ;For generating documentation
        ;; For the manual and the tests.
-       ("texlive" ,(texlive-union (list texlive-amsfonts
+       ("texlive" ,(texlive-updmap.cfg (list texlive-amsfonts
                                         texlive-epsf
                                         texlive-etoolbox
                                         texlive-latex-base
diff --git a/gnu/packages/radio.scm b/gnu/packages/radio.scm
index 0a4b623360..f7d348a242 100644
--- a/gnu/packages/radio.scm
+++ b/gnu/packages/radio.scm
@@ -303,7 +303,7 @@ used by RDS Spy, and audio files containing @dfn{multiplex} signals (MPX).")
        ("python-scipy" ,python-scipy)
        ("python-sphinx" ,python-sphinx)
        ("swig" ,swig)
-       ("texlive" ,(texlive-union (list texlive-amsfonts
+       ("texlive" ,(texlive-updmap.cfg (list texlive-amsfonts
                                         texlive-latex-amsmath
                                         ;; TODO: Add newunicodechar.
                                         texlive-latex-graphics)))
@@ -471,7 +471,7 @@ to access different radio hardware.")
        ("doxygen" ,doxygen)
        ("libtool" ,libtool)
        ("pkg-config" ,pkg-config)
-       ("texlive" ,(texlive-union (list texlive-amsfonts
+       ("texlive" ,(texlive-updmap.cfg (list texlive-amsfonts
                                         texlive-latex-amsmath
                                         ;; TODO: Add newunicodechar.
                                         texlive-latex-graphics)))))
diff --git a/gnu/packages/scheme.scm b/gnu/packages/scheme.scm
index a5a1793d3a..e16f4dc1b9 100644
--- a/gnu/packages/scheme.scm
+++ b/gnu/packages/scheme.scm
@@ -170,7 +170,7 @@
        ("autoconf" ,autoconf)
        ("automake" ,automake)
        ("libtool" ,libtool)
-       ("texlive" ,(texlive-union (list texlive-tex-texinfo)))
+       ("texlive" ,(texlive-updmap.cfg (list texlive-tex-texinfo)))
        ("texinfo" ,texinfo)
        ("m4" ,m4)))
     (inputs
diff --git a/gnu/packages/statistics.scm b/gnu/packages/statistics.scm
index c45544f52e..541753bb4a 100644
--- a/gnu/packages/statistics.scm
+++ b/gnu/packages/statistics.scm
@@ -337,7 +337,7 @@ as.POSIXct(if (\"\" != Sys.getenv(\"SOURCE_DATE_EPOCH\")) {\
        ("perl" ,perl)
        ("pkg-config" ,pkg-config)
        ("texinfo" ,texinfo) ; for building HTML manuals
-       ("texlive" ,(texlive-union (list texlive-ae
+       ("texlive" ,(texlive-updmap.cfg (list texlive-ae
                                         texlive-inconsolata
                                         texlive-fonts-ec
                                         texlive-amsfonts
diff --git a/gnu/packages/python-xyz.scm b/gnu/packages/python-xyz.scm
index 75051eca74..89ca39dcd4 100644
--- a/gnu/packages/python-xyz.scm
+++ b/gnu/packages/python-xyz.scm
@@ -4733,7 +4733,7 @@ color scales, and color space conversion easy.  It has support for:
        ("pkg-config" ,pkg-config)
        ("python-sphinx" ,python-sphinx)
        ("python-numpydoc" ,python-numpydoc)
-       ("texlive" ,(texlive-union (list texlive-fonts-cm-super
+       ("texlive" ,(texlive-updmap.cfg (list texlive-fonts-cm-super
                                         texlive-fonts-ec
                                         texlive-generic-ifxetex
                                         texlive-generic-pdftex
@@ -4799,7 +4799,7 @@ color scales, and color space conversion easy.  It has support for:
                     (sphinx-theme-checkout (assoc-ref inputs scipy-sphinx-theme))
                     (pyver ,(string-append "PYVER=")))
 
                ;; FIXME: this is needed to for texlive-union to generate
                ;; fonts, which are not found.
                (setenv "HOME" "/tmp")
 
@@ -5265,7 +5265,7 @@ toolkits.")
        ("python-ipykernel" ,python-ipykernel)
        ("python-mock" ,python-mock)
        ("graphviz" ,graphviz)
-       ("texlive" ,(texlive-union (list texlive-amsfonts
+       ("texlive" ,(texlive-updmap.cfg (list texlive-amsfonts
                                         texlive-latex-amsmath
                                         texlive-latex-enumitem
                                         texlive-latex-expdlist
@@ -7378,7 +7378,7 @@ computing.")
      `(("python-sphinx" ,python-sphinx)
        ("python-sphinx-rtd-theme" ,python-sphinx-rtd-theme)
        ;; FIXME: It's possible that a smaller union would work just as well.
-       ("texlive" ,(texlive-union (list texlive-amsfonts
+       ("texlive" ,(texlive-updmap.cfg (list texlive-amsfonts
                                         texlive-fonts-ec
                                         texlive-generic-ifxetex
                                         texlive-pdftex
@@ -22905,7 +22905,7 @@ By default it uses the open Python vulnerability database Safety DB.")
     (propagated-inputs
      `(("wheel" ,python-wheel)))
     (native-inputs
-     `(("texlive" ,(texlive-union (list texlive-amsfonts
+     `(("texlive" ,(texlive-updmap.cfg (list texlive-amsfonts
                                         texlive-fonts-ec
                                         texlive-latex-hyperref
                                         texlive-latex-oberdiek
@@ -4799,7 +4799,7 @@ color scales, and color space conversion easy.  It has support for:
                     (pyver ,(string-append "PYVER=")))
 
-               ;; FIXME: this is needed to for texlive-union to generate
+               ;; FIXME: this is needed to for texlive-updmap.cfg to generate
                ;; fonts, which are not found.
                (setenv "HOME" "/tmp")
diff --git a/gnu/packages/tex.scm b/gnu/packages/tex.scm
index 3d7aed30c7..fa5a0c6404 100644
--- a/gnu/packages/tex.scm
+++ b/gnu/packages/tex.scm
@@ -3009,7 +3009,7 @@ tables.")
                    (symlink pdftex (string-append out "/bin/pdfxmltex"))
                    #t)))))))
       (propagated-inputs
        ;; The following fonts are propagated as a texlive-union as the font
        ;; maps need to be recreated for the fonts to be usable.  They are
        ;; required by xmltex through mlnames.sty and unicode.sty.
        `(("texlive" ,(texlive-updmap.cfg
@@ -3843,7 +3843,7 @@ ones.")
 ;; For use in package definitions only
 (define-public texlive-tiny
   (package
-    (inherit (texlive-union))
+    (inherit (texlive-updmap.cfg))
     (name "texlive-tiny")
     (description "This is a very limited subset of the TeX Live distribution.
 It includes little more than the required set of LaTeX packages.")))
@@ -5803,7 +5803,7 @@ Simple Young tableaux.
                    (symlink pdftex (string-append out "/bin/pdfjadetex"))
                    #t)))))))
       (propagated-inputs
        ;; Propagate the texlive-union input used by xmltex, which provides the
        ;; required fonts for its use.
        `(("texlive-xmltex" ,texlive-xmltex)
          ("texlive-kpathsea" ,texlive-kpathsea))) ;for fmtutil.cnf template
@@ -6685,7 +6685,7 @@ develop documents with LaTeX, in a single application.")
              (delete-file "book.pdf")
              #t)))))
     (native-inputs
-     `(("texlive" ,(texlive-union (list texlive-amsfonts
+     `(("texlive" ,(texlive-updmap.cfg (list texlive-amsfonts
                                         texlive-fonts-adobe-palatino
                                         texlive-fonts-adobe-zapfding
                                         texlive-knuth-lib
@@ -6755,7 +6755,7 @@ and Karl Berry.")
        ("qtsvg" ,qtsvg)
        ("zlib" ,zlib)))
     (propagated-inputs
-     `(("texlive" ,(texlive-union (list texlive-fonts-ec)))))
+     `(("texlive" ,(texlive-updmap.cfg (list texlive-fonts-ec)))))
     (native-inputs
      `(("python" ,python)
        ("pkg-config" ,pkg-config)))
@@ -3009,7 +3009,7 @@ tables.")
                    #t)))))))
       (propagated-inputs
-       ;; The following fonts are propagated as a texlive-union as the font
+       ;; The following fonts are propagated as a texlive-updmap.cfg as the font
        ;; maps need to be recreated for the fonts to be usable.  They are
        ;; required by xmltex through mlnames.sty and unicode.sty.
@@ -5803,7 +5803,7 @@ Simple Young tableaux.
                    #t)))))))
       (propagated-inputs
-       ;; Propagate the texlive-union input used by xmltex, which provides the
+       ;; Propagate the texlive-updmap.cfg input used by xmltex, which provides the
        ;; required fonts for its use.
        `(("texlive-xmltex" ,texlive-xmltex)
-- 
2.29.2